@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2007, 2008 IBM Corporation and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2007, 2018 IBM Corporation and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  * 	IBM Corporation - initial API and implementation
@@ -17,17 +20,20 @@ import org.osgi.framework.BundleContext;
 public class Activator implements BundleActivator {
 
 	public static final String ID = "org.eclipse.equinox.p2.artifact.processors"; //$NON-NLS-1$
-	private static BundleContext context = null;
+	private static BundleContext _context = null;
 
 	public static BundleContext getContext() {
-		return context;
+		return _context;
 	}
 
+	@Override
 	public void start(BundleContext context) throws Exception {
-		Activator.context = context;
+		Activator._context = context;
 	}
 
+	@Override
 	public void stop(BundleContext context) throws Exception {
+		// nothing to do
 	}
 
 }
