@@ -1,9 +1,12 @@
 /*******************************************************************************
- * Copyright (c) 2009, Cloudsmith Inc and others.
- * All rights reserved. This program and the accompanying materials
- * are made available under the terms of the Eclipse Public License v1.0
+ * Copyright (c) 2009, 2018 Cloudsmith Inc and others.
+ *
+ * This program and the accompanying materials
+ * are made available under the terms of the Eclipse Public License 2.0
  * which accompanies this distribution, and is available at
- * http://www.eclipse.org/legal/epl-v10.html
+ * https://www.eclipse.org/legal/epl-2.0/
+ *
+ * SPDX-License-Identifier: EPL-2.0
  *
  * Contributors:
  *     Cloudsmith Inc. - initial API and implementation
@@ -16,8 +19,9 @@ import javax.servlet.http.HttpServletResponse;
 import org.osgi.service.http.HttpContext;
 
 /**
- * The SecureContext can be used to add basic authentication to a path.
- * This implementation requires the user "Aladdin" to log in with the password "open sesame".
+ * The SecureContext can be used to add basic authentication to a path. This
+ * implementation requires the user "Aladdin" to log in with the password "open
+ * sesame".
  */
 public class SecuredArtifactsContext extends SecureContext {
 
@@ -25,6 +29,7 @@ public class SecuredArtifactsContext extends SecureContext {
 		super(defaultContext);
 	}
 
+	@Override
 	public boolean handleSecurity(HttpServletRequest request, HttpServletResponse response) {
 		String path = request.getRequestURI();
 		if (path == null)
